function tfadjustexample()

% Request a file from the user
[wavname, wavdir] = uigetfile('*.wav', 'Select wave file');
wavfile = fullfile(wavdir, wavname);

% Find waveform metadata
[streamsize, Fs, bits] = wavread(wavfile, 'size');
samples = streamsize(1);
channels = streamsize(2);

% Read and transform first 1/10th second of data.
% native flag does not scale samples between [-1,1]
% older Matlab's might not support this in which case
% data values should be scaled by 2^(bits - 1)
x = wavread(wavfile, [1, round(.1*Fs)], 'native');
if channels > 1
    x = x(:,1);  % Select first channel
end
x = double(x);  % Cast to floating point

% calculate spectrum.  Returns power spectrum below Nyquist
% and associated frequency bin centers
[X, BinHz] = pwelch(x, length(x), 0, length(x), Fs);
X_dB = 10*log10(X);  % convert to dB

% Retrieve transfer function
adjust_dB = gettransferfn(wavfile, BinHz);
% Adjust spectrum for transfer function
X_dBadj = X_dB + adjust_dB;
semilogx(BinHz, X_dB, BinHz, X_dBadj)
xlabel('Hz')
ylabel('dB re 1\muP')
legend('uncorrected', 'corrected')
1;









